@@ -65,11 +65,10 @@ class System:
     
     def kcotd(self, p, glo, gnlo):    
         '''
-        Calculates k^(2l+1) cot(delta) as at a specificied momentum, p.
+        Calculates k^(2l+1) cot(delta) as at a specified momentum, p.
         '''
         xterm = self.interaction.counterterm.gen(glo, gnlo)
         v = self.v_tilde + xterm
-        print(p)
         scatter_temp = scatter.kcotdelta(p, v, self.q, self.wq, self.qmax, 2*self.mu)
         return p**(2*self.ell)*scatter_temp
     
@@ -86,6 +85,12 @@ class System:
                 self.qmax, 2*self.mu) for ki in ks]
         )
     
+
+    def kcotd_gen_pert1(self, ks, glo, gnlo):
+        v0 = self.v_tilde + self.interaction.counterterm.gen(glo, 0)
+        v1 = self.interaction.counterterm.gen(0, gnlo)
+        return np.array([scatter.kcotdelta_pert1(k, v0, v1, self.q, self.wq, self.qmax, 2*self.mu) for k in ks])
+    
     
     def kcotd_gen_fast(self, ks, glo, gnlo):    
         '''
@@ -99,6 +104,19 @@ class System:
             [cscatter.kcotdelta_py(ki, v, self.q, self.wq, self.qmax, self.ell, 2*self.mu) for ki in ks]
         )
     
+
+    def kcotd_gen_pert1_fast(self, ks, glo, gnlo):    
+        '''
+        Calculates k^(2l+1) cot(delta) as function of ks (array) so that we can
+        curve_fit the phaseshifts. Uses the C code inside the cc dir. Needs to
+        be compiled (try `make libs` inside cc) to a shared library first.
+        '''
+        v0 = self.v_tilde + self.interaction.counterterm.gen(glo, 0)
+        v1 = self.interaction.counterterm.gen(0, gnlo)
+        return np.array(
+            [cscatter.kcotdelta_pert1_py(ki, v0, v1, self.q, self.wq, self.qmax, self.ell, 2*self.mu) for ki in ks]
+        )
+    
     
     def effective_range_parameters(self, glo, gnlo, ks, expansion, p0=None, use_c=False):
         '''
